from Solarflare.solarflare import *
import datetime


class Daystar:

  def __init__(self, lat, long):
    self.lat = lat
    self.long = long

  def risetime(self, date=datetime.datetime.now()):
    return sunrise(self.lat, self.long, date)

  def settime(self, date=datetime.datetime.now()):
    return sunset(self.lat, self.long, date)

  def solarnoon(self, date=datetime.datetime.now()):
    return fromJulian(solar_transit(self.long, date))

  def hrangle(self, date=datetime.datetime.now()):
    return hour_angle(self.long, date)

  def coordinates(self, date=datetime.datetime.now()):
    return declination(date), right_ascension(date)



import setuptools
with open("README.md", "r") as fh:
  long_description = fh.read()
setuptools.setup(
  name="Daystar",
  version="0.0.2",
  author="Siddhu Pendyala",
  author_email="siddhu.pendyala@outlook.com",
  description="Sun calculation class from Solarflare module",
  long_description=long_description,  # don't touch this, this is your README.md
  long_description_content_type="text/markdown",
  packages=setuptools.find_packages(),
  classifiers=[
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
  ],
  python_requires='>=3.6',
  install_requires=["Solarflare"])
